==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/AuthenticatorKeyDuoAllOfProvider.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorKeyDuoAllOfProviderConfiguration;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorKeyDuoAllOfProvider
 */
@JsonPropertyOrder({ AuthenticatorKeyDuoAllOfProvider.JSON_PROPERTY_TYPE,
        AuthenticatorKeyDuoAllOfProvider.JSON_PROPERTY_CONFIGURATION })
@JsonTypeName("AuthenticatorKeyDuo_allOf_provider")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorKeyDuoAllOfProvider implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Provider type
     */
    public enum TypeEnum {
        DUO("DUO"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        TypeEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static TypeEnum fromValue(String value) {
            for (TypeEnum b : TypeEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_TYPE = "type";
    private TypeEnum type;

    public static final String JSON_PROPERTY_CONFIGURATION = "configuration";
    private AuthenticatorKeyDuoAllOfProviderConfiguration _configuration;

    public AuthenticatorKeyDuoAllOfProvider() {
    }

    public AuthenticatorKeyDuoAllOfProvider type(TypeEnum type) {

        this.type = type;
        return this;
    }

    /**
     * Provider type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Provider type")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public TypeEnum getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(TypeEnum type) {
        this.type = type;
    }

    public AuthenticatorKeyDuoAllOfProvider _configuration(
            AuthenticatorKeyDuoAllOfProviderConfiguration _configuration) {

        this._configuration = _configuration;
        return this;
    }

    /**
     * Get _configuration
     *
     * @return _configuration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorKeyDuoAllOfProviderConfiguration getConfiguration() {
        return _configuration;
    }

    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConfiguration(AuthenticatorKeyDuoAllOfProviderConfiguration _configuration) {
        this._configuration = _configuration;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorKeyDuoAllOfProvider authenticatorKeyDuoAllOfProvider = (AuthenticatorKeyDuoAllOfProvider) o;
        return Objects.equals(this.type, authenticatorKeyDuoAllOfProvider.type)
                && Objects.equals(this._configuration, authenticatorKeyDuoAllOfProvider._configuration);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, _configuration);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorKeyDuoAllOfProvider {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    _configuration: ").append(toIndentedString(_configuration)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/AuthenticatorKeyDuoAllOfProvider.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorKeyDuoAllOfProviderConfiguration;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorKeyDuoAllOfProvider
 */
@JsonPropertyOrder({ AuthenticatorKeyDuoAllOfProvider.JSON_PROPERTY_TYPE,
        AuthenticatorKeyDuoAllOfProvider.JSON_PROPERTY_CONFIGURATION })
@JsonTypeName("AuthenticatorKeyDuo_allOf_provider")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorKeyDuoAllOfProvider implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Provider type
     */
    public enum TypeEnum {
        DUO("DUO"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        TypeEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static TypeEnum fromValue(String value) {
            for (TypeEnum b : TypeEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_TYPE = "type";
    private TypeEnum type;

    public static final String JSON_PROPERTY_CONFIGURATION = "configuration";
    private AuthenticatorKeyDuoAllOfProviderConfiguration _configuration;

    public AuthenticatorKeyDuoAllOfProvider() {
    }

    public AuthenticatorKeyDuoAllOfProvider type(TypeEnum type) {

        this.type = type;
        return this;
    }

    /**
     * Provider type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Provider type")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public TypeEnum getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(TypeEnum type) {
        this.type = type;
    }

    public AuthenticatorKeyDuoAllOfProvider _configuration(
            AuthenticatorKeyDuoAllOfProviderConfiguration _configuration) {

        this._configuration = _configuration;
        return this;
    }

    /**
     * Get _configuration
     *
     * @return _configuration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorKeyDuoAllOfProviderConfiguration getConfiguration() {
        return _configuration;
    }

    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConfiguration(AuthenticatorKeyDuoAllOfProviderConfiguration _configuration) {
        this._configuration = _configuration;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorKeyDuoAllOfProvider authenticatorKeyDuoAllOfProvider = (AuthenticatorKeyDuoAllOfProvider) o;
        return Objects.equals(this.type, authenticatorKeyDuoAllOfProvider.type)
                && Objects.equals(this._configuration, authenticatorKeyDuoAllOfProvider._configuration);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, _configuration);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorKeyDuoAllOfProvider {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    _configuration: ").append(toIndentedString(_configuration)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
